@@ -19,32 +19,14 @@ from os_brick import exception
 from os_brick.initiator.connectors import rbd
 from os_brick.initiator import linuxrbd
 from os_brick.privileged import rootwrap as priv_rootwrap
+from os_brick.tests.initiator.connectors import test_base_rbd
 from os_brick.tests.initiator import test_connector
 from os_brick import utils
 
 
 @ddt.ddt
-class RBDConnectorTestCase(test_connector.ConnectorTestCase):
-
-    def setUp(self):
-        super(RBDConnectorTestCase, self).setUp()
-
-        self.user = 'fake_user'
-        self.pool = 'fake_pool'
-        self.volume = 'fake_volume'
-        self.clustername = 'fake_ceph'
-        self.hosts = ['192.168.10.2']
-        self.ports = ['6789']
-        self.keyring = "[client.cinder]\n  key = test\n"
-
-        self.connection_properties = {
-            'auth_username': self.user,
-            'name': '%s/%s' % (self.pool, self.volume),
-            'cluster_name': self.clustername,
-            'hosts': self.hosts,
-            'ports': self.ports,
-            'keyring': self.keyring,
-        }
+class RBDConnectorTestCase(test_base_rbd.RBDConnectorTestMixin,
+                           test_connector.ConnectorTestCase):
 
     def test_get_search_path(self):
         rbd_connector = rbd.RBDConnector(None)
@@ -140,31 +122,8 @@ class RBDConnectorTestCase(test_connector.ConnectorTestCase):
                               conn._check_or_get_keyring_contents, keyring,
                               'cluster', 'user')
 
-    @ddt.data((['192.168.1.1', '192.168.1.2'],
-               ['192.168.1.1', '192.168.1.2']),
-              (['3ffe:1900:4545:3:200:f8ff:fe21:67cf',
-                'fe80:0:0:0:200:f8ff:fe21:67cf'],
-               ['[3ffe:1900:4545:3:200:f8ff:fe21:67cf]',
-                '[fe80:0:0:0:200:f8ff:fe21:67cf]']),
-              (['foobar', 'fizzbuzz'], ['foobar', 'fizzbuzz']),
-              (['192.168.1.1',
-                '3ffe:1900:4545:3:200:f8ff:fe21:67cf',
-                'hello, world!'],
-               ['192.168.1.1',
-                '[3ffe:1900:4545:3:200:f8ff:fe21:67cf]',
-                'hello, world!']))
-    @ddt.unpack
-    def test_sanitize_mon_host(self, hosts_in, hosts_out):
-        conn = rbd.RBDConnector(None)
-        self.assertEqual(hosts_out, conn._sanitize_mon_hosts(hosts_in))
-
-    @ddt.data(
-        "ceph version 14.2.9 (581f...) nautilus (stable)",
-        "ceph version 14.2.11-99-gaf0268dc91 (af0268dc9) nautilus (stable)")
-    @mock.patch.object(priv_rootwrap, 'execute')
     @mock.patch('os_brick.initiator.connectors.rbd.tempfile.mkstemp')
-    def test_create_ceph_conf(self, ceph_version, mock_mkstemp, mock_execute):
-        mock_execute.return_value = (ceph_version, None)
+    def test_create_ceph_conf(self, mock_mkstemp):
         mockopen = mock.mock_open()
         fd = mock.sentinel.fd
         tmpfile = mock.sentinel.tmpfile
@@ -177,37 +136,10 @@ class RBDConnectorTestCase(test_connector.ConnectorTestCase):
                 self.keyring)
         self.assertEqual(conf_path, tmpfile)
         mock_mkstemp.assert_called_once_with(prefix='brickrbd_')
+        # Bug #1865754 - make sure generated config file has a '[global]'
+        # section
         _, args, _ = mockopen().writelines.mock_calls[0]
-        self.assertNotIn('[global]', args[0])
-
-    @ddt.data(
-        ("ceph version 15.2.3 (d289...) octopus (stable)", True),
-        ("ceph version 15.2.3-00-d289 (d289) octopus (stable)", True),
-        ("ceph version 14.2.9 (581f...) nautilus (stable)", False),
-        ("ceph version 14.2.11-99-ga..1 (af0268dc9) nautilus (stable)", False))
-    @mock.patch.object(priv_rootwrap, 'execute')
-    @mock.patch('os_brick.initiator.connectors.rbd.tempfile.mkstemp')
-    @ddt.unpack
-    def test_create_ceph_conf_octopus(self, ceph_version, is_octopus,
-                                      mock_mkstemp, mock_execute):
-        mock_execute.return_value = (ceph_version, None)
-        mockopen = mock.mock_open()
-        fd = mock.sentinel.fd
-        tmpfile = mock.sentinel.tmpfile
-        mock_mkstemp.return_value = (fd, tmpfile)
-
-        with mock.patch('os.fdopen', mockopen, create=True):
-            rbd_connector = rbd.RBDConnector(None)
-            conf_path = rbd_connector._create_ceph_conf(
-                self.hosts, self.ports, self.clustername, self.user,
-                self.keyring)
-        self.assertEqual(conf_path, tmpfile)
-        mock_mkstemp.assert_called_once_with(prefix='brickrbd_')
-        _, args, _ = mockopen().writelines.mock_calls[0]
-        if is_octopus:
-            self.assertIn('[global]', args[0])
-        else:
-            self.assertNotIn('[global]', args[0])
+        self.assertIn('[global]', args[0])
 
     @mock.patch('os_brick.privileged.rbd.root_create_ceph_conf')
     def test_create_non_openstack_config(self, mock_priv_create):
@@ -283,16 +215,6 @@ class RBDConnectorTestCase(test_connector.ConnectorTestCase):
                          'type': 'block'}
         self.assertEqual(expected_info, device_info)
 
-    @mock.patch.object(priv_rootwrap, 'execute', return_value=None)
-    def test_connect_local_volume_without_auth(self, mock_execute):
-        rbd_connector = rbd.RBDConnector(None, do_local_attach=True)
-        conn = {'name': 'pool/image',
-                'hosts': ['192.168.10.2'],
-                'ports': ['6789']}
-        self.assertRaises(exception.BrickException,
-                          rbd_connector.connect_volume,
-                          conn)
-
     @mock.patch('os_brick.initiator.connectors.rbd.'
                 'RBDConnector._local_attach_volume')
     def test_connect_volume_local(self, mock_local_attach):
@@ -354,20 +276,13 @@ class RBDConnectorTestCase(test_connector.ConnectorTestCase):
 
         mock_delete.assert_called_once_with(mock_rbd_cfg.return_value)
 
-    @ddt.data(
-        "ceph version 14.2.9 (581f...) nautilus (stable)",
-        "ceph version 14.2.11-99-gaf0268dc91 (af0268dc9) nautilus (stable)")
-    @mock.patch.object(priv_rootwrap, 'execute')
     @mock.patch('os_brick.initiator.linuxrbd.rbd')
     @mock.patch('os_brick.initiator.linuxrbd.rados')
     @mock.patch.object(linuxrbd.RBDVolumeIOWrapper, 'close')
-    def test_disconnect_volume(self, ceph_version, volume_close, mock_rados,
-                               mock_rbd, mock_execute):
+    def test_disconnect_volume(self, volume_close, mock_rados, mock_rbd):
         """Test the disconnect volume case."""
-        mock_execute.return_value = (ceph_version, None)
         rbd_connector = rbd.RBDConnector(None)
         device_info = rbd_connector.connect_volume(self.connection_properties)
-
         rbd_connector.disconnect_volume(
             self.connection_properties, device_info)
 
@@ -528,20 +443,6 @@ class RBDConnectorTestCase(test_connector.ConnectorTestCase):
         mock_delete.assert_called_once_with(mock_config.return_value)
         mock_open.assert_not_called()
 
-    def test__get_rbd_args(self):
-        res = rbd.RBDConnector._get_rbd_args(self.connection_properties, None)
-        expected = ['--id', self.user,
-                    '--mon_host', self.hosts[0] + ':' + self.ports[0]]
-        self.assertEqual(expected, res)
-
-    def test__get_rbd_args_with_conf(self):
-        res = rbd.RBDConnector._get_rbd_args(self.connection_properties,
-                                             mock.sentinel.conf_path)
-        expected = ['--id', self.user,
-                    '--mon_host', self.hosts[0] + ':' + self.ports[0],
-                    '--conf', mock.sentinel.conf_path]
-        self.assertEqual(expected, res)
-
     @mock.patch.object(rbd.RBDConnector, '_get_rbd_args')
     @mock.patch.object(rbd.RBDConnector, '_execute')
     def test_find_root_device(self, mock_execute, mock_args):
