@@ -41,7 +41,9 @@ class ZeroIntervalLoopingCall(loopingcall.FixedIntervalLoopingCall):
 
 class ConnectorUtilsTestCase(test_base.TestCase):
 
-    @mock.patch.object(nvmeof.NVMeOFConnector, '_get_system_uuid',
+    @mock.patch.object(nvmeof.NVMeOFConnector, '_get_host_uuid',
+                       return_value=None)
+    @mock.patch.object(nvmeof.NVMeOFConnector, '_get_host_nqn',
                        return_value=None)
     @mock.patch.object(iscsi.ISCSIConnector, 'get_initiator',
                        return_value='fakeinitiator')
@@ -56,6 +58,7 @@ class ConnectorUtilsTestCase(test_base.TestCase):
                                              multipath_result,
                                              mock_wwnns, mock_wwpns,
                                              mock_initiator,
+                                             mock_nqn,
                                              mock_sysuuid,
                                              host='fakehost'):
         props_actual = connector.get_connector_properties('sudo',
@@ -195,7 +198,7 @@ class ConnectorTestCase(test_base.TestCase):
     def test_get_connector_mapping_win32(self):
         mapping_win32 = connector.get_connector_mapping()
         self.assertTrue('ISCSI' in mapping_win32)
-        self.assertFalse('RBD' in mapping_win32)
+        self.assertTrue('RBD' in mapping_win32)
         self.assertFalse('STORPOOL' in mapping_win32)
 
     @mock.patch('os_brick.initiator.connector.platform.machine')
@@ -226,9 +229,6 @@ class ConnectorTestCase(test_base.TestCase):
                                                    arch='s390x')
         self.assertEqual("FibreChannelConnectorS390X", obj.__class__.__name__)
 
-        obj = connector.InitiatorConnector.factory('aoe', None, arch='x86_64')
-        self.assertEqual("AoEConnector", obj.__class__.__name__)
-
         obj = connector.InitiatorConnector.factory(
             'nfs', None, nfs_mount_point_base='/mnt/test')
         self.assertEqual("RemoteFsConnector", obj.__class__.__name__)
@@ -262,10 +262,6 @@ class ConnectorTestCase(test_base.TestCase):
             arch='x86_64')
         self.assertEqual("RemoteFsConnector", obj.__class__.__name__)
 
-        obj = connector.InitiatorConnector.factory(
-            "disco", None, arch='x86_64')
-        self.assertEqual("DISCOConnector", obj.__class__.__name__)
-
         self.assertRaises(exception.InvalidConnectorProtocol,
                           connector.InitiatorConnector.factory,
                           "bogus", None)
